# 确保命令模块被导入，从而完成注册到 CommandRegistry
from .docx_file_parse_cmd import DocxFileParseCommand
from .docx_file_partition_cmd import DocxFilePartitionCommand 
from .file_type_identification_cmd import FileTypeIdentificationCommand
from .rtf_file_parse_cmd import RTFFileParseCommand 
from .enhance_level_cmd import EnhanceLevelCommand